@@ -39,7 +39,7 @@ __all__ = [
 from yapsy.IPlugin import IPlugin
 from doit.cmd_base import Command as DoitCommand
 
-from .utils import LOGGER
+from .utils import LOGGER, first_line
 
 
 class BasePlugin(IPlugin):
@@ -104,7 +104,7 @@ DoitCommand.help = help
 
 
 class BaseTask(BasePlugin):
-    """PLugins of this type are task generators."""
+    """Plugins of this type are task generators."""
 
     name = "dummy_task"
 
@@ -116,9 +116,17 @@ class BaseTask(BasePlugin):
         """Task generator."""
         raise NotImplementedError()
 
+    def group_task(self):
+        """dict for group task"""
+        return {
+            'basename': self.name,
+            'name': None,
+            'doc': first_line(self.__doc__),
+        }
+
 
 class Task(BaseTask):
-    """PLugins of this type are task generators."""
+    """Plugins of this type are task generators."""
 
 
 class LateTask(BaseTask):
@@ -140,7 +148,7 @@ class TemplateSystem(BasePlugin):
         """Returns filenames which are dependencies for a template."""
         raise NotImplementedError()
 
-    def render_template(name, output_name, context):
+    def render_template(self, template_name, output_name, context):
         """Renders template to a file using context.
 
         This must save the data to output_name *and* return it
