@@ -33,6 +33,8 @@ import sys
 from nikola.plugin_categories import Command
 from nikola import utils
 
+LOGGER = utils.get_logger('new_post')
+
 
 def filter_post_pages(compiler, is_post, compilers, post_pages):
     """Given a compiler ("markdown", "rest"), and whether it's meant for
@@ -98,8 +100,8 @@ def get_date(schedule=False, rule=None, last_date=None, force_today=False):
         try:
             from dateutil import rrule
         except ImportError:
-            utils.LOGGER.error('To use the --schedule switch of new_post, '
-                               'you have to install the "dateutil" package.')
+            LOGGER.error('To use the --schedule switch of new_post, '
+                         'you have to install the "dateutil" package.')
             rrule = None
     if schedule and rrule and rule:
         if last_date and last_date.tzinfo:
@@ -108,7 +110,7 @@ def get_date(schedule=False, rule=None, last_date=None, force_today=False):
         try:
             rule_ = rrule.rrulestr(rule, dtstart=last_date)
         except Exception:
-            utils.LOGGER.error('Unable to parse rule string, using current time.')
+            LOGGER.error('Unable to parse rule string, using current time.')
         else:
             # Try to post today, instead of tomorrow, if no other post today.
             if force_today:
@@ -216,7 +218,7 @@ class CommandNewPost(Command):
                 self.site.config['post_pages'])
 
         if post_format not in compiler_names:
-            utils.LOGGER.error("Unknown post format " + post_format)
+            LOGGER.error("Unknown post format " + post_format)
             return
         compiler_plugin = self.site.plugin_manager.getPluginByName(
             post_format, "PageCompiler").plugin_object
@@ -264,7 +266,7 @@ class CommandNewPost(Command):
 
         if (not onefile and os.path.isfile(meta_path)) or \
                 os.path.isfile(txt_path):
-            utils.LOGGER.error("The title already exists!")
+            LOGGER.error("The title already exists!")
             exit()
 
         d_name = os.path.dirname(txt_path)
@@ -279,5 +281,5 @@ class CommandNewPost(Command):
                 fd.write('\n'.join(data))
             with codecs.open(txt_path, "wb+", "utf8") as fd:
                 fd.write("Write your post here.")
-            utils.LOGGER.notice("Your post's metadata is at: {0}".format(meta_path))
-        utils.LOGGER.notice("Your post's text is at: {0}".format(txt_path))
+            LOGGER.notice("Your post's metadata is at: {0}".format(meta_path))
+        LOGGER.notice("Your post's text is at: {0}".format(txt_path))
