@@ -31,14 +31,23 @@ from collections import defaultdict
 import os
 import re
 import string
+try:
+    from urlparse import urljoin
+except ImportError:
+    from urllib.parse import urljoin  # NOQA
 
 import lxml.html
+try:
+    import pyphen
+except ImportError:
+    pyphen = None
 
-from .utils import (to_datetime, slugify, bytes_str, Functionary, LocaleBorg)
+from .utils import (to_datetime, slugify, bytes_str, Functionary, LocaleBorg, unicode_str)
 
 __all__ = ['Post']
 
 TEASER_REGEXP = re.compile('<!--\s*TEASER_END(:(.+))?\s*-->', re.IGNORECASE)
+READ_MORE_LINK = '<p class="more"><a href="{link}">{read_more}…</a></p>'
 
 
 class Post(object):
@@ -50,6 +59,7 @@ class Post(object):
         translations, default_lang, base_url, messages, template_name,
         file_metadata_regexp=None, strip_indexes=False, index_file='index.html',
         tzinfo=None, current_time=None, skip_untranslated=False, pretty_urls=False,
+        hyphenate=False,
     ):
         """Initialize post.
 
@@ -79,6 +89,8 @@ class Post(object):
         self.skip_untranslated = skip_untranslated
         self._template_name = template_name
         self.is_two_file = True
+        self.hyphenate = hyphenate
+        self._reading_time = None
 
         default_metadata = get_meta(self, file_metadata_regexp)
 
@@ -130,6 +142,9 @@ class Post(object):
             if 'retired' in self._tags[lang]:
                 is_retired = True
                 self._tags[lang].remove('retired')
+            if 'private' in self._tags[lang]:
+                is_retired = True
+                self._tags[lang].remove('private')
 
         # While draft comes from the tags, it's not really a tag
         self.is_draft = is_draft
@@ -303,7 +318,7 @@ class Post(object):
         else:
             return '.'.join((self.base_path, sorted(self.translated_to)[0]))
 
-    def text(self, lang=None, teaser_only=False, strip_html=False):
+    def text(self, lang=None, teaser_only=False, strip_html=False, really_absolute=False):
         """Read the post file for that language and return its contents.
 
         teaser_only=True breaks at the teaser marker and returns only the teaser.
@@ -327,7 +342,12 @@ class Post(object):
                 return ""
             # let other errors raise
             raise(e)
-        document.make_links_absolute(self.permalink(lang=lang))
+        base_url = self.permalink(lang=lang, absolute=really_absolute)
+        document.make_links_absolute(base_url)
+
+        if self.hyphenate:
+            hyphenate(document, lang)
+
         data = lxml.html.tostring(document, encoding='unicode')
         # data here is a full HTML doc, including HTML and BODY tags
         # which is not ideal (Issue #464)
@@ -342,10 +362,14 @@ class Post(object):
         if teaser_only:
             teaser = TEASER_REGEXP.split(data)[0]
             if teaser != data:
-                teaser_str = TEASER_REGEXP.search(data).groups()[-1] or \
-                    self.messages[lang]["Read more"] + '...'
-                teaser += '<p><a href="{0}">{1}</a></p>'.format(
-                    self.permalink(lang), teaser_str)
+                if TEASER_REGEXP.search(data).groups()[-1]:
+                    teaser += '<p class="more"><a href="{0}">{1}</a></p>'.format(
+                        self.permalink(lang, absolute=really_absolute),
+                        TEASER_REGEXP.search(data).groups()[-1])
+                else:
+                    teaser += READ_MORE_LINK.format(
+                        link=self.permalink(lang, absolute=really_absolute),
+                        read_more=self.messages[lang]["Read more"])
                 # This closes all open tags and sanitizes the broken HTML
                 document = lxml.html.fromstring(teaser)
                 data = lxml.html.tostring(document, encoding='unicode')
@@ -355,6 +379,17 @@ class Post(object):
             data = content.text_content().strip()  # No whitespace wanted.
         return data
 
+    @property
+    def reading_time(self):
+        """Reading time based on length of text.
+        """
+        if self._reading_time is None:
+            text = self.text(strip_html=True)
+            words_per_minute = 180
+            words = len(text.split())
+            self._reading_time = int(round(words / words_per_minute)) or 1
+        return self._reading_time
+
     def source_link(self, lang=None):
         """Return absolute link to the post's source."""
         return "/" + self.destination_path(
@@ -391,11 +426,9 @@ class Post(object):
         else:
             pieces += [self.meta[lang]['slug'] + extension]
         pieces = [_f for _f in pieces if _f and _f != '.']
+        link = '/' + '/'.join(pieces)
         if absolute:
-            pieces = [self.base_url] + pieces
-        else:
-            pieces = [""] + pieces
-        link = "/".join(pieces)
+            link = urljoin(self.base_url, link)
         index_len = len(self.index_file)
         if self.strip_indexes and link[-(1 + index_len):] == '/' + self.index_file:
             return link[:-index_len]
@@ -450,6 +483,8 @@ def get_metadata_from_file(source_path, lang=None):
         with codecs.open(source_path, "r", "utf8") as meta_file:
             meta_data = [x.strip() for x in meta_file.readlines()]
         return _get_metadata_from_file(meta_data)
+    except (UnicodeDecodeError, UnicodeEncodeError):
+        raise ValueError('Error reading {0}: Nikola only supports UTF-8 files'.format(source_path))
     except Exception:  # The file may not exist, for multilingual sites
         return {}
 
@@ -571,8 +606,8 @@ def get_meta(post, file_metadata_regexp=None, lang=None):
 
         if 'slug' not in meta:
             # If no slug is found in the metadata use the filename
-            meta['slug'] = slugify(os.path.splitext(
-                os.path.basename(post.source_path))[0])
+            meta['slug'] = slugify(unicode_str(os.path.splitext(
+                os.path.basename(post.source_path))[0]))
 
         if 'title' not in meta:
             # If no title is found, use the filename without extension
@@ -580,3 +615,34 @@ def get_meta(post, file_metadata_regexp=None, lang=None):
                 os.path.basename(post.source_path))[0]
 
     return meta
+
+
+def hyphenate(dom, lang):
+    if pyphen is not None:
+        hyphenator = pyphen.Pyphen(lang=lang)
+        for tag in ('p', 'li', 'span'):
+            for node in dom.xpath("//%s[not(parent::pre)]" % tag):
+                insert_hyphens(node, hyphenator)
+    return dom
+
+
+def insert_hyphens(node, hyphenator):
+    textattrs = ('text', 'tail')
+    if isinstance(node, lxml.etree._Entity):
+        # HTML entities have no .text
+        textattrs = ('tail',)
+    for attr in textattrs:
+        text = getattr(node, attr)
+        if not text:
+            continue
+        new_data = ' '.join([hyphenator.inserted(w, hyphen='\u00AD')
+                             for w in text.split(' ')])
+        # Spaces are trimmed, we have to add them manually back
+        if text[0].isspace():
+            new_data = ' ' + new_data
+        if text[-1].isspace():
+            new_data += ' '
+        setattr(node, attr, new_data)
+
+    for child in node.iterchildren():
+        insert_hyphens(child, hyphenator)
