@@ -6,12 +6,20 @@
 """ Base class for Nikola test cases """
 
 
-__all__ = ["BaseTestCase"]
-
+__all__ = ["BaseTestCase", "cd"]
 
+from contextlib import contextmanager
+import os
 import sys
 import unittest
 
+import logbook
+
+# Make logbook shutup
+from nikola.utils import LOGGER
+
+LOGGER.handlers.append(logbook.TestHandler())
+
 
 if sys.version_info < (2, 7):
 
@@ -56,3 +64,11 @@ if sys.version_info < (2, 7):
 
 else:
     BaseTestCase = unittest.TestCase
+
+
+@contextmanager
+def cd(path):
+    old_dir = os.getcwd()
+    os.chdir(path)
+    yield
+    os.chdir(old_dir)
