@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 import unittest
 import os
 import re
@@ -8,7 +8,7 @@ from io import StringIO
 
 import mock
 
-from context import nikola
+from .context import nikola
 from lxml import etree
 
 
@@ -20,6 +20,7 @@ class RSSFeedTest(unittest.TestCase):
                         mock.Mock(return_value=({'title': 'post title',
                                                  'slug': 'awesome_article',
                                                  'date': '2012-10-01 22:41',
+                                                 'author': None,
                                                  'tags': 'tags', 'link':
                                                  'link', 'description':
                                                  'description'}))):
